from kervi.hal import SensorDeviceDriver

class DummySensorDeviceDriver(SensorDeviceDriver):
    def __init__(self):
        SensorDeviceDriver.__init__(self)
        self.value = 0
        self.delta = 4

    def read_value(self):
        self.value += self.delta
        if self.value == 100:
            self.delta *= -1
        if self.value == 0:
            self.delta *= -1
        return self.value

    @property
    def type(self):
        return "temperature"

    @property
    def unit(self):
        return "C"

    @property
    def max(self):
        return 100

    @property
    def min(self):
        return 0


class DummyMultiDimSensorDeviceDriver(SensorDeviceDriver):
    def __init__(self):
        self.value = 0
        self.delta = 4

    def read_value(self):
        self.value += self.delta
        if self.value == 100:
            self.delta *= -1
        if self.value == 0:
            self.delta *= -1
        return [self.value, self.value + 1, self.value +2]

    @property
    def dimensions(self):
        return 3

    @property
    def dimension_labels(self):
        return ["heading", "pitch", "roll"]

    @property
    def type(self):
        return "position"

    @property
    def unit(self):
        return "degree"



from kervi.hal import OneWireSensorDeviceDriver

class DS18XXXDeviceDriver(OneWireSensorDeviceDriver):
    def __init__(self, address):
        OneWireSensorDeviceDriver.__init__(self, address)
        # Check that mode is valid.

    def read_value(self):
        data = self.one_wire.read()
        equals_pos = data.find('t=')
        if equals_pos != -1:
            temp_string = data[equals_pos+2:]
            temp_c = float(temp_string) / 1000.0
            return temp_c

    @property
    def type(self):
        return "temperature"

    @property
    def unit(self):
        return "C"


# Copyright (c) 2016, Tim Wentzlau
# Licensed under MIT

""" Module that defines core cpu sensors """

from kervi.hal import SensorDeviceDriver, HAL_DRIVER_ID

class CPUTempSensorDeviceDriver(SensorDeviceDriver):
    """ Sensor that mesures cpu temp on host """
    def __init__(self):
        SensorDeviceDriver.__init__(self)

    def read_value(self):
        if HAL_DRIVER_ID == "kervi.platforms.raspberry":
            return int(open('/sys/class/thermal/thermal_zone0/temp').read()) / 1e3
        return 0

    @property
    def max(self):
        return 150

    @property
    def min(self):
        return 0

    @property
    def type(self):
        return "temperature"

    @property
    def unit(self):
        return "C"
